Changelog
---------

Unreleased
~~~~~~~~~~

0.0.3 (2015-07-15)
~~~~~~~~~~~~~~~~~~~

- Adds an email property to the handler.
  [href]

- Adds reopen ticket function.
  [msom]

0.0.2 (2015-07-14)
~~~~~~~~~~~~~~~~~~~

- Adds a handler_id to easily query for a handler record.
  [href]

- Adds accept/close ticket functions.
  [href]

- Adds a ticket collection that supports pagination and filter.
  [href]

0.0.1 (2015-07-10)
~~~~~~~~~~~~~~~~~~~

- Initial Release
